# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetKeyResult',
    'AwaitableGetKeyResult',
    'get_key',
    'get_key_output',
]

@pulumi.output_type
class GetKeyResult:
    """
    A collection of values returned by getKey.
    """
    def __init__(__self__, created_time=None, description=None, id=None, key_id=None, key_material_expire_time=None, key_name=None, key_spec=None, key_state=None, key_usage=None, keyring_name=None, last_rotation_time=None, multi_region=None, multi_region_configuration=None, origin=None, protection_level=None, rotate_state=None, schedule_delete_time=None, schedule_rotation_time=None, tags=None, trn=None, updated_time=None):
        if created_time and not isinstance(created_time, int):
            raise TypeError("Expected argument 'created_time' to be a int")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_id and not isinstance(key_id, str):
            raise TypeError("Expected argument 'key_id' to be a str")
        pulumi.set(__self__, "key_id", key_id)
        if key_material_expire_time and not isinstance(key_material_expire_time, str):
            raise TypeError("Expected argument 'key_material_expire_time' to be a str")
        pulumi.set(__self__, "key_material_expire_time", key_material_expire_time)
        if key_name and not isinstance(key_name, str):
            raise TypeError("Expected argument 'key_name' to be a str")
        pulumi.set(__self__, "key_name", key_name)
        if key_spec and not isinstance(key_spec, str):
            raise TypeError("Expected argument 'key_spec' to be a str")
        pulumi.set(__self__, "key_spec", key_spec)
        if key_state and not isinstance(key_state, str):
            raise TypeError("Expected argument 'key_state' to be a str")
        pulumi.set(__self__, "key_state", key_state)
        if key_usage and not isinstance(key_usage, str):
            raise TypeError("Expected argument 'key_usage' to be a str")
        pulumi.set(__self__, "key_usage", key_usage)
        if keyring_name and not isinstance(keyring_name, str):
            raise TypeError("Expected argument 'keyring_name' to be a str")
        pulumi.set(__self__, "keyring_name", keyring_name)
        if last_rotation_time and not isinstance(last_rotation_time, str):
            raise TypeError("Expected argument 'last_rotation_time' to be a str")
        pulumi.set(__self__, "last_rotation_time", last_rotation_time)
        if multi_region and not isinstance(multi_region, bool):
            raise TypeError("Expected argument 'multi_region' to be a bool")
        pulumi.set(__self__, "multi_region", multi_region)
        if multi_region_configuration and not isinstance(multi_region_configuration, dict):
            raise TypeError("Expected argument 'multi_region_configuration' to be a dict")
        pulumi.set(__self__, "multi_region_configuration", multi_region_configuration)
        if origin and not isinstance(origin, str):
            raise TypeError("Expected argument 'origin' to be a str")
        pulumi.set(__self__, "origin", origin)
        if protection_level and not isinstance(protection_level, str):
            raise TypeError("Expected argument 'protection_level' to be a str")
        pulumi.set(__self__, "protection_level", protection_level)
        if rotate_state and not isinstance(rotate_state, str):
            raise TypeError("Expected argument 'rotate_state' to be a str")
        pulumi.set(__self__, "rotate_state", rotate_state)
        if schedule_delete_time and not isinstance(schedule_delete_time, str):
            raise TypeError("Expected argument 'schedule_delete_time' to be a str")
        pulumi.set(__self__, "schedule_delete_time", schedule_delete_time)
        if schedule_rotation_time and not isinstance(schedule_rotation_time, str):
            raise TypeError("Expected argument 'schedule_rotation_time' to be a str")
        pulumi.set(__self__, "schedule_rotation_time", schedule_rotation_time)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if trn and not isinstance(trn, str):
            raise TypeError("Expected argument 'trn' to be a str")
        pulumi.set(__self__, "trn", trn)
        if updated_time and not isinstance(updated_time, int):
            raise TypeError("Expected argument 'updated_time' to be a int")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.int:
        """
        密钥创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        密钥描述:长度为 0   - 8192 个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> builtins.str:
        """
        密钥唯一标识符，UUID形式。
        """
        return pulumi.get(self, "key_id")

    @property
    @pulumi.getter(name="keyMaterialExpireTime")
    def key_material_expire_time(self) -> builtins.str:
        """
        密钥材料过期时间，当值为空时表示不会过期。
        """
        return pulumi.get(self, "key_material_expire_time")

    @property
    @pulumi.getter(name="keyName")
    def key_name(self) -> builtins.str:
        """
        主密钥名称，长度为 2   - 31 个字符，合法字符：[a-zA-Z0-9-_]。
        """
        return pulumi.get(self, "key_name")

    @property
    @pulumi.getter(name="keySpec")
    def key_spec(self) -> builtins.str:
        """
        对称密钥：SYMMETRIC*256，SYMMETRIC*128，非对称密钥：RSA*2048，RSA*3072，RSA*4096，EC*P256，EC*P256K，EC*P384，EC*P521，EC*SM2。
        """
        return pulumi.get(self, "key_spec")

    @property
    @pulumi.getter(name="keyState")
    def key_state(self) -> builtins.str:
        """
        密钥状态：Enable，Disable，PendingDelete，Archived，PendingImport。
        """
        return pulumi.get(self, "key_state")

    @property
    @pulumi.getter(name="keyUsage")
    def key_usage(self) -> builtins.str:
        """
        密钥用途，取值：ENCRYPT*DECRYPT，SIGN*VERIFY，GENERATE*VERIFY*MAC。
        """
        return pulumi.get(self, "key_usage")

    @property
    @pulumi.getter(name="keyringName")
    def keyring_name(self) -> builtins.str:
        """
        密钥环名称，长度为 2   - 31 个字符，合法字符：[a-zA-Z0-9-_]。
        """
        return pulumi.get(self, "keyring_name")

    @property
    @pulumi.getter(name="lastRotationTime")
    def last_rotation_time(self) -> builtins.str:
        """
        密钥最后轮转时间。
        """
        return pulumi.get(self, "last_rotation_time")

    @property
    @pulumi.getter(name="multiRegion")
    def multi_region(self) -> builtins.bool:
        """
        是否为 Multi-region 类型的主密钥。
        """
        return pulumi.get(self, "multi_region")

    @property
    @pulumi.getter(name="multiRegionConfiguration")
    def multi_region_configuration(self) -> 'outputs.GetKeyMultiRegionConfigurationResult':
        """
        Multi-region key 配置信息。
        """
        return pulumi.get(self, "multi_region_configuration")

    @property
    @pulumi.getter
    def origin(self) -> builtins.str:
        """
        密钥来源，取值：CloudKMS，External，ExternalKeyStore。
        """
        return pulumi.get(self, "origin")

    @property
    @pulumi.getter(name="protectionLevel")
    def protection_level(self) -> builtins.str:
        """
        密钥保护级别，取值：SOFTWARE，HSM。
        """
        return pulumi.get(self, "protection_level")

    @property
    @pulumi.getter(name="rotateState")
    def rotate_state(self) -> builtins.str:
        """
        密钥轮转状态，取值：Enable，Disable。
        """
        return pulumi.get(self, "rotate_state")

    @property
    @pulumi.getter(name="scheduleDeleteTime")
    def schedule_delete_time(self) -> builtins.str:
        """
        密钥删除时间。
        """
        return pulumi.get(self, "schedule_delete_time")

    @property
    @pulumi.getter(name="scheduleRotationTime")
    def schedule_rotation_time(self) -> builtins.str:
        """
        密钥轮转时间。
        """
        return pulumi.get(self, "schedule_rotation_time")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetKeyTagResult']:
        """
        KMS密钥的标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def trn(self) -> builtins.str:
        """
        资源名称，格式应为 trn:${Service}:${Region}:${AccountID}:${ResourcePath}。
        """
        return pulumi.get(self, "trn")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.int:
        """
        密钥更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetKeyResult(GetKeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKeyResult(
            created_time=self.created_time,
            description=self.description,
            id=self.id,
            key_id=self.key_id,
            key_material_expire_time=self.key_material_expire_time,
            key_name=self.key_name,
            key_spec=self.key_spec,
            key_state=self.key_state,
            key_usage=self.key_usage,
            keyring_name=self.keyring_name,
            last_rotation_time=self.last_rotation_time,
            multi_region=self.multi_region,
            multi_region_configuration=self.multi_region_configuration,
            origin=self.origin,
            protection_level=self.protection_level,
            rotate_state=self.rotate_state,
            schedule_delete_time=self.schedule_delete_time,
            schedule_rotation_time=self.schedule_rotation_time,
            tags=self.tags,
            trn=self.trn,
            updated_time=self.updated_time)


def get_key(id: Optional[builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKeyResult:
    """
    Data Source schema for Byteplus::KMS::Key


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:kms/getKey:getKey', __args__, opts=opts, typ=GetKeyResult).value

    return AwaitableGetKeyResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        key_id=pulumi.get(__ret__, 'key_id'),
        key_material_expire_time=pulumi.get(__ret__, 'key_material_expire_time'),
        key_name=pulumi.get(__ret__, 'key_name'),
        key_spec=pulumi.get(__ret__, 'key_spec'),
        key_state=pulumi.get(__ret__, 'key_state'),
        key_usage=pulumi.get(__ret__, 'key_usage'),
        keyring_name=pulumi.get(__ret__, 'keyring_name'),
        last_rotation_time=pulumi.get(__ret__, 'last_rotation_time'),
        multi_region=pulumi.get(__ret__, 'multi_region'),
        multi_region_configuration=pulumi.get(__ret__, 'multi_region_configuration'),
        origin=pulumi.get(__ret__, 'origin'),
        protection_level=pulumi.get(__ret__, 'protection_level'),
        rotate_state=pulumi.get(__ret__, 'rotate_state'),
        schedule_delete_time=pulumi.get(__ret__, 'schedule_delete_time'),
        schedule_rotation_time=pulumi.get(__ret__, 'schedule_rotation_time'),
        tags=pulumi.get(__ret__, 'tags'),
        trn=pulumi.get(__ret__, 'trn'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_key_output(id: Optional[pulumi.Input[builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKeyResult]:
    """
    Data Source schema for Byteplus::KMS::Key


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:kms/getKey:getKey', __args__, opts=opts, typ=GetKeyResult)
    return __ret__.apply(lambda __response__: GetKeyResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        key_id=pulumi.get(__response__, 'key_id'),
        key_material_expire_time=pulumi.get(__response__, 'key_material_expire_time'),
        key_name=pulumi.get(__response__, 'key_name'),
        key_spec=pulumi.get(__response__, 'key_spec'),
        key_state=pulumi.get(__response__, 'key_state'),
        key_usage=pulumi.get(__response__, 'key_usage'),
        keyring_name=pulumi.get(__response__, 'keyring_name'),
        last_rotation_time=pulumi.get(__response__, 'last_rotation_time'),
        multi_region=pulumi.get(__response__, 'multi_region'),
        multi_region_configuration=pulumi.get(__response__, 'multi_region_configuration'),
        origin=pulumi.get(__response__, 'origin'),
        protection_level=pulumi.get(__response__, 'protection_level'),
        rotate_state=pulumi.get(__response__, 'rotate_state'),
        schedule_delete_time=pulumi.get(__response__, 'schedule_delete_time'),
        schedule_rotation_time=pulumi.get(__response__, 'schedule_rotation_time'),
        tags=pulumi.get(__response__, 'tags'),
        trn=pulumi.get(__response__, 'trn'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

import types

__config__ = pulumi.Config('bytepluscc')


class _ExportableConfig(types.ModuleType):
    @property
    def access_key(self) -> Optional[str]:
        """
        The Access Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_ACCESS_KEY`
        environment variable
        """
        return __config__.get('accessKey') or _utilities.get_env('BYTEPLUS_ACCESS_KEY')

    @property
    def assume_role(self) -> Optional[str]:
        """
        An `assume_role` block (documented below). Only one `assume_role` block may be in the configuration.
        """
        return __config__.get('assumeRole')

    @property
    def customer_headers(self) -> Optional[str]:
        """
        CUSTOMER HEADERS for Byteplus Provider. The customer_headers field uses commas (,) to separate multiple headers, and
        colons (:) to separate each header key from its corresponding value.
        """
        return __config__.get('customerHeaders') or _utilities.get_env('BYTEPLUS_CUSTOMER_HEADERS')

    @property
    def disable_ssl(self) -> Optional[bool]:
        """
        Disable SSL for Byteplus Provider
        """
        return __config__.get_bool('disableSsl') or _utilities.get_env_bool('BYTEPLUS_DISABLE_SSL')

    @property
    def endpoints(self) -> Optional[str]:
        """
        An `endpoints` block (documented below). Only one `endpoints` block may be in the configuration.
        """
        return __config__.get('endpoints')

    @property
    def proxy_url(self) -> Optional[str]:
        """
        PROXY URL for Byteplus Provider
        """
        return __config__.get('proxyUrl') or _utilities.get_env('BYTEPLUS_PROXY_URL')

    @property
    def region(self) -> Optional[str]:
        """
        The Region for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_REGION` environment
        variable
        """
        return __config__.get('region') or _utilities.get_env('BYTEPLUS_REGION')

    @property
    def secret_key(self) -> Optional[str]:
        """
        he Secret Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_SECRET_KEY`
        environment variable
        """
        return __config__.get('secretKey') or _utilities.get_env('BYTEPLUS_SECRET_KEY')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNodePoolResult',
    'AwaitableGetNodePoolResult',
    'get_node_pool',
    'get_node_pool_output',
]

@pulumi.output_type
class GetNodePoolResult:
    """
    A collection of values returned by getNodePool.
    """
    def __init__(__self__, auto_scaling=None, cluster_id=None, created_time=None, id=None, kubernetes_config=None, management=None, name=None, node_config=None, node_pool_id=None, node_statistics=None, retain_resources=None, status=None, tags=None, updated_time=None):
        if auto_scaling and not isinstance(auto_scaling, dict):
            raise TypeError("Expected argument 'auto_scaling' to be a dict")
        pulumi.set(__self__, "auto_scaling", auto_scaling)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kubernetes_config and not isinstance(kubernetes_config, dict):
            raise TypeError("Expected argument 'kubernetes_config' to be a dict")
        pulumi.set(__self__, "kubernetes_config", kubernetes_config)
        if management and not isinstance(management, dict):
            raise TypeError("Expected argument 'management' to be a dict")
        pulumi.set(__self__, "management", management)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_config and not isinstance(node_config, dict):
            raise TypeError("Expected argument 'node_config' to be a dict")
        pulumi.set(__self__, "node_config", node_config)
        if node_pool_id and not isinstance(node_pool_id, str):
            raise TypeError("Expected argument 'node_pool_id' to be a str")
        pulumi.set(__self__, "node_pool_id", node_pool_id)
        if node_statistics and not isinstance(node_statistics, dict):
            raise TypeError("Expected argument 'node_statistics' to be a dict")
        pulumi.set(__self__, "node_statistics", node_statistics)
        if retain_resources and not isinstance(retain_resources, list):
            raise TypeError("Expected argument 'retain_resources' to be a list")
        pulumi.set(__self__, "retain_resources", retain_resources)
        if status and not isinstance(status, dict):
            raise TypeError("Expected argument 'status' to be a dict")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="autoScaling")
    def auto_scaling(self) -> 'outputs.GetNodePoolAutoScalingResult':
        """
        节点池伸缩策略配置。
        """
        return pulumi.get(self, "auto_scaling")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        节点池所在集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建节点池的时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="kubernetesConfig")
    def kubernetes_config(self) -> 'outputs.GetNodePoolKubernetesConfigResult':
        """
        节点池 Kubernetes 相关配置。
        """
        return pulumi.get(self, "kubernetes_config")

    @property
    @pulumi.getter
    def management(self) -> 'outputs.GetNodePoolManagementResult':
        """
        托管节点池配置。
        """
        return pulumi.get(self, "management")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        节点池名称。同一个集群下，节点池名称必须唯一。支持大小写英文字母、汉字、数字、短划线（-），长度限制为 2～64 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeConfig")
    def node_config(self) -> 'outputs.GetNodePoolNodeConfigResult':
        """
        节点池中云服务器（ECS）实例配置。
        """
        return pulumi.get(self, "node_config")

    @property
    @pulumi.getter(name="nodePoolId")
    def node_pool_id(self) -> builtins.str:
        """
        节点池 ID 。
        """
        return pulumi.get(self, "node_pool_id")

    @property
    @pulumi.getter(name="nodeStatistics")
    def node_statistics(self) -> 'outputs.GetNodePoolNodeStatisticsResult':
        """
        节点池中的节点统计。
        """
        return pulumi.get(self, "node_statistics")

    @property
    @pulumi.getter(name="retainResources")
    def retain_resources(self) -> Sequence[builtins.str]:
        """
        删除节点池时，指定保留的相关资源，取值：取值为空：（默认值）删除关联资源。Ecs：删除节点池时，保留节点池中的云服务器（ECS）实例。若指定的节点池内存在包年包月的云服务器实例，且未选择保留云服务器，则该接口仅从节点池中移除云服务器实例，不会删除。您可以通过云服务器控制台或云服务器API查询到该实例，并按需执行后续操作。
        """
        return pulumi.get(self, "retain_resources")

    @property
    @pulumi.getter
    def status(self) -> 'outputs.GetNodePoolStatusResult':
        """
        节点池状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetNodePoolTagResult']:
        """
        节点池的标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新节点池的时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetNodePoolResult(GetNodePoolResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodePoolResult(
            auto_scaling=self.auto_scaling,
            cluster_id=self.cluster_id,
            created_time=self.created_time,
            id=self.id,
            kubernetes_config=self.kubernetes_config,
            management=self.management,
            name=self.name,
            node_config=self.node_config,
            node_pool_id=self.node_pool_id,
            node_statistics=self.node_statistics,
            retain_resources=self.retain_resources,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_node_pool(id: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNodePoolResult:
    """
    Data Source schema for Byteplus::VKE::NodePool


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vke/getNodePool:getNodePool', __args__, opts=opts, typ=GetNodePoolResult).value

    return AwaitableGetNodePoolResult(
        auto_scaling=pulumi.get(__ret__, 'auto_scaling'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        created_time=pulumi.get(__ret__, 'created_time'),
        id=pulumi.get(__ret__, 'id'),
        kubernetes_config=pulumi.get(__ret__, 'kubernetes_config'),
        management=pulumi.get(__ret__, 'management'),
        name=pulumi.get(__ret__, 'name'),
        node_config=pulumi.get(__ret__, 'node_config'),
        node_pool_id=pulumi.get(__ret__, 'node_pool_id'),
        node_statistics=pulumi.get(__ret__, 'node_statistics'),
        retain_resources=pulumi.get(__ret__, 'retain_resources'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_node_pool_output(id: Optional[pulumi.Input[builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNodePoolResult]:
    """
    Data Source schema for Byteplus::VKE::NodePool


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vke/getNodePool:getNodePool', __args__, opts=opts, typ=GetNodePoolResult)
    return __ret__.apply(lambda __response__: GetNodePoolResult(
        auto_scaling=pulumi.get(__response__, 'auto_scaling'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        created_time=pulumi.get(__response__, 'created_time'),
        id=pulumi.get(__response__, 'id'),
        kubernetes_config=pulumi.get(__response__, 'kubernetes_config'),
        management=pulumi.get(__response__, 'management'),
        name=pulumi.get(__response__, 'name'),
        node_config=pulumi.get(__response__, 'node_config'),
        node_pool_id=pulumi.get(__response__, 'node_pool_id'),
        node_statistics=pulumi.get(__response__, 'node_statistics'),
        retain_resources=pulumi.get(__response__, 'retain_resources'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, created_time=None, description=None, display_name=None, email=None, id=None, identity_type=None, password=None, password_reset_required=None, phone=None, source=None, updated_time=None, user_id=None, user_name=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identity_type and not isinstance(identity_type, str):
            raise TypeError("Expected argument 'identity_type' to be a str")
        pulumi.set(__self__, "identity_type", identity_type)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if password_reset_required and not isinstance(password_reset_required, bool):
            raise TypeError("Expected argument 'password_reset_required' to be a bool")
        pulumi.set(__self__, "password_reset_required", password_reset_required)
        if phone and not isinstance(phone, str):
            raise TypeError("Expected argument 'phone' to be a str")
        pulumi.set(__self__, "phone", phone)
        if source and not isinstance(source, str):
            raise TypeError("Expected argument 'source' to be a str")
        pulumi.set(__self__, "source", source)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        用户描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        用户显示名。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        邮箱。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="identityType")
    def identity_type(self) -> builtins.str:
        """
        身份类型。
        """
        return pulumi.get(self, "identity_type")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        密码。密码长度8-32位字符,包含大写字母、小写字母、数字和物特殊符号至少3种。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordResetRequired")
    def password_reset_required(self) -> builtins.bool:
        """
        首次登陆需不需要重置密码。
        """
        return pulumi.get(self, "password_reset_required")

    @property
    @pulumi.getter
    def phone(self) -> builtins.str:
        """
        手机号。
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter
    def source(self) -> builtins.str:
        """
        用户来源。
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        """
        用户id。
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        用户名。
        """
        return pulumi.get(self, "user_name")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            created_time=self.created_time,
            description=self.description,
            display_name=self.display_name,
            email=self.email,
            id=self.id,
            identity_type=self.identity_type,
            password=self.password,
            password_reset_required=self.password_reset_required,
            phone=self.phone,
            source=self.source,
            updated_time=self.updated_time,
            user_id=self.user_id,
            user_name=self.user_name)


def get_user(id: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    Data Source schema for Byteplus::CloudIdentity::User


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cloudidentity/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        identity_type=pulumi.get(__ret__, 'identity_type'),
        password=pulumi.get(__ret__, 'password'),
        password_reset_required=pulumi.get(__ret__, 'password_reset_required'),
        phone=pulumi.get(__ret__, 'phone'),
        source=pulumi.get(__ret__, 'source'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        user_id=pulumi.get(__ret__, 'user_id'),
        user_name=pulumi.get(__ret__, 'user_name'))
def get_user_output(id: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    Data Source schema for Byteplus::CloudIdentity::User


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cloudidentity/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        email=pulumi.get(__response__, 'email'),
        id=pulumi.get(__response__, 'id'),
        identity_type=pulumi.get(__response__, 'identity_type'),
        password=pulumi.get(__response__, 'password'),
        password_reset_required=pulumi.get(__response__, 'password_reset_required'),
        phone=pulumi.get(__response__, 'phone'),
        source=pulumi.get(__response__, 'source'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        user_id=pulumi.get(__response__, 'user_id'),
        user_name=pulumi.get(__response__, 'user_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *
from ._inputs import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_bytepluscc.alb as __alb
    alb = __alb
    import pulumi_bytepluscc.apig as __apig
    apig = __apig
    import pulumi_bytepluscc.autoscaling as __autoscaling
    autoscaling = __autoscaling
    import pulumi_bytepluscc.bmq as __bmq
    bmq = __bmq
    import pulumi_bytepluscc.cdn as __cdn
    cdn = __cdn
    import pulumi_bytepluscc.cen as __cen
    cen = __cen
    import pulumi_bytepluscc.clb as __clb
    clb = __clb
    import pulumi_bytepluscc.cloudidentity as __cloudidentity
    cloudidentity = __cloudidentity
    import pulumi_bytepluscc.config as __config
    config = __config
    import pulumi_bytepluscc.cr as __cr
    cr = __cr
    import pulumi_bytepluscc.dns as __dns
    dns = __dns
    import pulumi_bytepluscc.ecs as __ecs
    ecs = __ecs
    import pulumi_bytepluscc.escloud as __escloud
    escloud = __escloud
    import pulumi_bytepluscc.firewallcenter as __firewallcenter
    firewallcenter = __firewallcenter
    import pulumi_bytepluscc.hbase as __hbase
    hbase = __hbase
    import pulumi_bytepluscc.iam as __iam
    iam = __iam
    import pulumi_bytepluscc.kafka as __kafka
    kafka = __kafka
    import pulumi_bytepluscc.kms as __kms
    kms = __kms
    import pulumi_bytepluscc.natgateway as __natgateway
    natgateway = __natgateway
    import pulumi_bytepluscc.organization as __organization
    organization = __organization
    import pulumi_bytepluscc.privatelink as __privatelink
    privatelink = __privatelink
    import pulumi_bytepluscc.rdsmysql as __rdsmysql
    rdsmysql = __rdsmysql
    import pulumi_bytepluscc.redis as __redis
    redis = __redis
    import pulumi_bytepluscc.storageebs as __storageebs
    storageebs = __storageebs
    import pulumi_bytepluscc.vefaas as __vefaas
    vefaas = __vefaas
    import pulumi_bytepluscc.vepfs as __vepfs
    vepfs = __vepfs
    import pulumi_bytepluscc.vke as __vke
    vke = __vke
    import pulumi_bytepluscc.vpc as __vpc
    vpc = __vpc
else:
    alb = _utilities.lazy_import('pulumi_bytepluscc.alb')
    apig = _utilities.lazy_import('pulumi_bytepluscc.apig')
    autoscaling = _utilities.lazy_import('pulumi_bytepluscc.autoscaling')
    bmq = _utilities.lazy_import('pulumi_bytepluscc.bmq')
    cdn = _utilities.lazy_import('pulumi_bytepluscc.cdn')
    cen = _utilities.lazy_import('pulumi_bytepluscc.cen')
    clb = _utilities.lazy_import('pulumi_bytepluscc.clb')
    cloudidentity = _utilities.lazy_import('pulumi_bytepluscc.cloudidentity')
    config = _utilities.lazy_import('pulumi_bytepluscc.config')
    cr = _utilities.lazy_import('pulumi_bytepluscc.cr')
    dns = _utilities.lazy_import('pulumi_bytepluscc.dns')
    ecs = _utilities.lazy_import('pulumi_bytepluscc.ecs')
    escloud = _utilities.lazy_import('pulumi_bytepluscc.escloud')
    firewallcenter = _utilities.lazy_import('pulumi_bytepluscc.firewallcenter')
    hbase = _utilities.lazy_import('pulumi_bytepluscc.hbase')
    iam = _utilities.lazy_import('pulumi_bytepluscc.iam')
    kafka = _utilities.lazy_import('pulumi_bytepluscc.kafka')
    kms = _utilities.lazy_import('pulumi_bytepluscc.kms')
    natgateway = _utilities.lazy_import('pulumi_bytepluscc.natgateway')
    organization = _utilities.lazy_import('pulumi_bytepluscc.organization')
    privatelink = _utilities.lazy_import('pulumi_bytepluscc.privatelink')
    rdsmysql = _utilities.lazy_import('pulumi_bytepluscc.rdsmysql')
    redis = _utilities.lazy_import('pulumi_bytepluscc.redis')
    storageebs = _utilities.lazy_import('pulumi_bytepluscc.storageebs')
    vefaas = _utilities.lazy_import('pulumi_bytepluscc.vefaas')
    vepfs = _utilities.lazy_import('pulumi_bytepluscc.vepfs')
    vke = _utilities.lazy_import('pulumi_bytepluscc.vke')
    vpc = _utilities.lazy_import('pulumi_bytepluscc.vpc')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "bytepluscc",
  "mod": "alb/certificate",
  "fqn": "pulumi_bytepluscc.alb",
  "classes": {
   "bytepluscc:alb/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "alb/listener",
  "fqn": "pulumi_bytepluscc.alb",
  "classes": {
   "bytepluscc:alb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/customDomain",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/customDomain:CustomDomain": "CustomDomain"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/gateway",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/gatewayService",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/gatewayService:GatewayService": "GatewayService"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/upstream",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/upstream:Upstream": "Upstream"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "apig/upstreamSource",
  "fqn": "pulumi_bytepluscc.apig",
  "classes": {
   "bytepluscc:apig/upstreamSource:UpstreamSource": "UpstreamSource"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "autoscaling/scalingConfiguration",
  "fqn": "pulumi_bytepluscc.autoscaling",
  "classes": {
   "bytepluscc:autoscaling/scalingConfiguration:ScalingConfiguration": "ScalingConfiguration"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "autoscaling/scalingGroup",
  "fqn": "pulumi_bytepluscc.autoscaling",
  "classes": {
   "bytepluscc:autoscaling/scalingGroup:ScalingGroup": "ScalingGroup"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "bmq/instance",
  "fqn": "pulumi_bytepluscc.bmq",
  "classes": {
   "bytepluscc:bmq/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "cdn/shareConfig",
  "fqn": "pulumi_bytepluscc.cdn",
  "classes": {
   "bytepluscc:cdn/shareConfig:ShareConfig": "ShareConfig"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "cen/cen",
  "fqn": "pulumi_bytepluscc.cen",
  "classes": {
   "bytepluscc:cen/cen:Cen": "Cen"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "clb/listener",
  "fqn": "pulumi_bytepluscc.clb",
  "classes": {
   "bytepluscc:clb/listener:Listener": "Listener"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "clb/rule",
  "fqn": "pulumi_bytepluscc.clb",
  "classes": {
   "bytepluscc:clb/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "cloudidentity/user",
  "fqn": "pulumi_bytepluscc.cloudidentity",
  "classes": {
   "bytepluscc:cloudidentity/user:User": "User"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "cr/repository",
  "fqn": "pulumi_bytepluscc.cr",
  "classes": {
   "bytepluscc:cr/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "dns/zone",
  "fqn": "pulumi_bytepluscc.dns",
  "classes": {
   "bytepluscc:dns/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "ecs/image",
  "fqn": "pulumi_bytepluscc.ecs",
  "classes": {
   "bytepluscc:ecs/image:Image": "Image"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "ecs/instance",
  "fqn": "pulumi_bytepluscc.ecs",
  "classes": {
   "bytepluscc:ecs/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "escloud/instance",
  "fqn": "pulumi_bytepluscc.escloud",
  "classes": {
   "bytepluscc:escloud/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "firewallcenter/dnsControlPolicy",
  "fqn": "pulumi_bytepluscc.firewallcenter",
  "classes": {
   "bytepluscc:firewallcenter/dnsControlPolicy:DnsControlPolicy": "DnsControlPolicy"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "hbase/instance",
  "fqn": "pulumi_bytepluscc.hbase",
  "classes": {
   "bytepluscc:hbase/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "iam/policy",
  "fqn": "pulumi_bytepluscc.iam",
  "classes": {
   "bytepluscc:iam/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "iam/project",
  "fqn": "pulumi_bytepluscc.iam",
  "classes": {
   "bytepluscc:iam/project:Project": "Project"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "iam/role",
  "fqn": "pulumi_bytepluscc.iam",
  "classes": {
   "bytepluscc:iam/role:Role": "Role"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "iam/user",
  "fqn": "pulumi_bytepluscc.iam",
  "classes": {
   "bytepluscc:iam/user:User": "User"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "kafka/topic",
  "fqn": "pulumi_bytepluscc.kafka",
  "classes": {
   "bytepluscc:kafka/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "kms/key",
  "fqn": "pulumi_bytepluscc.kms",
  "classes": {
   "bytepluscc:kms/key:Key": "Key"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "natgateway/dnatentry",
  "fqn": "pulumi_bytepluscc.natgateway",
  "classes": {
   "bytepluscc:natgateway/dnatentry:Dnatentry": "Dnatentry"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "natgateway/natIp",
  "fqn": "pulumi_bytepluscc.natgateway",
  "classes": {
   "bytepluscc:natgateway/natIp:NatIp": "NatIp"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "natgateway/ngw",
  "fqn": "pulumi_bytepluscc.natgateway",
  "classes": {
   "bytepluscc:natgateway/ngw:Ngw": "Ngw"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "natgateway/snatentry",
  "fqn": "pulumi_bytepluscc.natgateway",
  "classes": {
   "bytepluscc:natgateway/snatentry:Snatentry": "Snatentry"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "organization/unit",
  "fqn": "pulumi_bytepluscc.organization",
  "classes": {
   "bytepluscc:organization/unit:Unit": "Unit"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "privatelink/endpointService",
  "fqn": "pulumi_bytepluscc.privatelink",
  "classes": {
   "bytepluscc:privatelink/endpointService:EndpointService": "EndpointService"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "rdsmysql/dbAccount",
  "fqn": "pulumi_bytepluscc.rdsmysql",
  "classes": {
   "bytepluscc:rdsmysql/dbAccount:DbAccount": "DbAccount"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "rdsmysql/instance",
  "fqn": "pulumi_bytepluscc.rdsmysql",
  "classes": {
   "bytepluscc:rdsmysql/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "redis/instance",
  "fqn": "pulumi_bytepluscc.redis",
  "classes": {
   "bytepluscc:redis/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "storageebs/snapshot",
  "fqn": "pulumi_bytepluscc.storageebs",
  "classes": {
   "bytepluscc:storageebs/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "storageebs/volume",
  "fqn": "pulumi_bytepluscc.storageebs",
  "classes": {
   "bytepluscc:storageebs/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vefaas/kafkaTrigger",
  "fqn": "pulumi_bytepluscc.vefaas",
  "classes": {
   "bytepluscc:vefaas/kafkaTrigger:KafkaTrigger": "KafkaTrigger"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vefaas/sandbox",
  "fqn": "pulumi_bytepluscc.vefaas",
  "classes": {
   "bytepluscc:vefaas/sandbox:Sandbox": "Sandbox"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vepfs/instance",
  "fqn": "pulumi_bytepluscc.vepfs",
  "classes": {
   "bytepluscc:vepfs/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vke/addon",
  "fqn": "pulumi_bytepluscc.vke",
  "classes": {
   "bytepluscc:vke/addon:Addon": "Addon"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vke/cluster",
  "fqn": "pulumi_bytepluscc.vke",
  "classes": {
   "bytepluscc:vke/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vke/nodePool",
  "fqn": "pulumi_bytepluscc.vke",
  "classes": {
   "bytepluscc:vke/nodePool:NodePool": "NodePool"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vke/permission",
  "fqn": "pulumi_bytepluscc.vke",
  "classes": {
   "bytepluscc:vke/permission:Permission": "Permission"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vpc/eni",
  "fqn": "pulumi_bytepluscc.vpc",
  "classes": {
   "bytepluscc:vpc/eni:Eni": "Eni"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vpc/securityGroup",
  "fqn": "pulumi_bytepluscc.vpc",
  "classes": {
   "bytepluscc:vpc/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vpc/subnet",
  "fqn": "pulumi_bytepluscc.vpc",
  "classes": {
   "bytepluscc:vpc/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "bytepluscc",
  "mod": "vpc/vpc",
  "fqn": "pulumi_bytepluscc.vpc",
  "classes": {
   "bytepluscc:vpc/vpc:Vpc": "Vpc"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "bytepluscc",
  "token": "pulumi:providers:bytepluscc",
  "fqn": "pulumi_bytepluscc",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NatIpArgs', 'NatIp']

@pulumi.input_type
class NatIpArgs:
    def __init__(__self__, *,
                 nat_gateway_id: pulumi.Input[builtins.str],
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NatIp resource.
        :param pulumi.Input[builtins.str] nat_gateway_id: 私网NAT网关ID。
        :param pulumi.Input[builtins.str] nat_ip: 中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        :param pulumi.Input[builtins.str] nat_ip_description: 中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] nat_ip_name: 中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip is not None:
            pulumi.set(__self__, "nat_ip", nat_ip)
        if nat_ip_description is not None:
            pulumi.set(__self__, "nat_ip_description", nat_ip_description)
        if nat_ip_name is not None:
            pulumi.set(__self__, "nat_ip_name", nat_ip_name)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        私网NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        """
        return pulumi.get(self, "nat_ip")

    @nat_ip.setter
    def nat_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip", value)

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "nat_ip_description")

    @nat_ip_description.setter
    def nat_ip_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_description", value)

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_name")

    @nat_ip_name.setter
    def nat_ip_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_name", value)


@pulumi.input_type
class _NatIpState:
    def __init__(__self__, *,
                 is_default: Optional[pulumi.Input[builtins.bool]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 using_status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NatIp resources.
        :param pulumi.Input[builtins.bool] is_default: 是否为默认中转IP。true：是。false：否。
        :param pulumi.Input[builtins.str] nat_gateway_id: 私网NAT网关ID。
        :param pulumi.Input[builtins.str] nat_ip: 中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        :param pulumi.Input[builtins.str] nat_ip_description: 中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] nat_ip_id: 中转IP的ID。
        :param pulumi.Input[builtins.str] nat_ip_name: 中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        :param pulumi.Input[builtins.str] status: 中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        :param pulumi.Input[builtins.str] using_status: 中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip is not None:
            pulumi.set(__self__, "nat_ip", nat_ip)
        if nat_ip_description is not None:
            pulumi.set(__self__, "nat_ip_description", nat_ip_description)
        if nat_ip_id is not None:
            pulumi.set(__self__, "nat_ip_id", nat_ip_id)
        if nat_ip_name is not None:
            pulumi.set(__self__, "nat_ip_name", nat_ip_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if using_status is not None:
            pulumi.set(__self__, "using_status", using_status)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否为默认中转IP。true：是。false：否。
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私网NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        """
        return pulumi.get(self, "nat_ip")

    @nat_ip.setter
    def nat_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip", value)

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "nat_ip_description")

    @nat_ip_description.setter
    def nat_ip_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_description", value)

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @nat_ip_id.setter
    def nat_ip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_id", value)

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_name")

    @nat_ip_name.setter
    def nat_ip_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_ip_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")

    @using_status.setter
    def using_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "using_status", value)


@pulumi.type_token("bytepluscc:natgateway/natIp:NatIp")
class NatIp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        从私网NAT网关所属子网分配，用于IP地址转换。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_nat_ip_demo = bytepluscc.natgateway.NatIp("NatGatewayNatIpDemo",
            nat_gateway_id="ngw-2hgk22kpfp5a874wjohxxxxx",
            nat_ip_description="NatGatewayNatIpDemo description",
            nat_ip_name="NatGatewayNatIpDemo",
            nat_ip="192.168.xxx.xx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/natIp:NatIp example "nat_ip_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] nat_gateway_id: 私网NAT网关ID。
        :param pulumi.Input[builtins.str] nat_ip: 中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        :param pulumi.Input[builtins.str] nat_ip_description: 中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] nat_ip_name: 中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NatIpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        从私网NAT网关所属子网分配，用于IP地址转换。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_nat_ip_demo = bytepluscc.natgateway.NatIp("NatGatewayNatIpDemo",
            nat_gateway_id="ngw-2hgk22kpfp5a874wjohxxxxx",
            nat_ip_description="NatGatewayNatIpDemo description",
            nat_ip_name="NatGatewayNatIpDemo",
            nat_ip="192.168.xxx.xx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/natIp:NatIp example "nat_ip_id"
        ```

        :param str resource_name: The name of the resource.
        :param NatIpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NatIpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
                 nat_ip_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NatIpArgs.__new__(NatIpArgs)

            if nat_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'nat_gateway_id'")
            __props__.__dict__["nat_gateway_id"] = nat_gateway_id
            __props__.__dict__["nat_ip"] = nat_ip
            __props__.__dict__["nat_ip_description"] = nat_ip_description
            __props__.__dict__["nat_ip_name"] = nat_ip_name
            __props__.__dict__["is_default"] = None
            __props__.__dict__["nat_ip_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["using_status"] = None
        super(NatIp, __self__).__init__(
            'bytepluscc:natgateway/natIp:NatIp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_default: Optional[pulumi.Input[builtins.bool]] = None,
            nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_description: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_id: Optional[pulumi.Input[builtins.str]] = None,
            nat_ip_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            using_status: Optional[pulumi.Input[builtins.str]] = None) -> 'NatIp':
        """
        Get an existing NatIp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] is_default: 是否为默认中转IP。true：是。false：否。
        :param pulumi.Input[builtins.str] nat_gateway_id: 私网NAT网关ID。
        :param pulumi.Input[builtins.str] nat_ip: 中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        :param pulumi.Input[builtins.str] nat_ip_description: 中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] nat_ip_id: 中转IP的ID。
        :param pulumi.Input[builtins.str] nat_ip_name: 中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        :param pulumi.Input[builtins.str] status: 中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        :param pulumi.Input[builtins.str] using_status: 中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NatIpState.__new__(_NatIpState)

        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["nat_ip"] = nat_ip
        __props__.__dict__["nat_ip_description"] = nat_ip_description
        __props__.__dict__["nat_ip_id"] = nat_ip_id
        __props__.__dict__["nat_ip_name"] = nat_ip_name
        __props__.__dict__["status"] = status
        __props__.__dict__["using_status"] = using_status
        return NatIp(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[builtins.bool]:
        """
        是否为默认中转IP。true：是。false：否。
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        私网NAT网关ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的地址。若不填，则系统自动从私网NAT网关所在子网随机分配一个空闲的IP地址。
        """
        return pulumi.get(self, "nat_ip")

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的描述。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "nat_ip_description")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_id")

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短划线（-）。不填默认为中转IP的ID。
        """
        return pulumi.get(self, "nat_ip_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的状态。Creating：创建中。Available：可用。Deleting：删除中。Deleted：已删除。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="usingStatus")
    def using_status(self) -> pulumi.Output[builtins.str]:
        """
        中转IP的使用状态。Idle：未使用。UsedBySnat：被SNAT规则使用。UsedByDnat：被DNAT规则使用。UsedByNat：被SNAT/DNAT规则同时使用。
        """
        return pulumi.get(self, "using_status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'InstanceCapacity',
    'InstanceConfigureNode',
    'InstanceInstanceShard',
    'InstanceInstanceShardServerNode',
    'InstanceTag',
    'InstanceVisitAddr',
    'GetInstanceCapacityResult',
    'GetInstanceConfigureNodeResult',
    'GetInstanceInstanceShardResult',
    'GetInstanceInstanceShardServerNodeResult',
    'GetInstanceTagResult',
    'GetInstanceVisitAddrResult',
]

@pulumi.output_type
class InstanceCapacity(dict):
    def __init__(__self__, *,
                 total: Optional[builtins.int] = None,
                 used: Optional[builtins.int] = None):
        """
        :param builtins.int total: 当前实例的内存总容量。单位：MiB。
        :param builtins.int used: 当前实例已用容量。单位：MiB。
        """
        if total is not None:
            pulumi.set(__self__, "total", total)
        if used is not None:
            pulumi.set(__self__, "used", used)

    @property
    @pulumi.getter
    def total(self) -> Optional[builtins.int]:
        """
        当前实例的内存总容量。单位：MiB。
        """
        return pulumi.get(self, "total")

    @property
    @pulumi.getter
    def used(self) -> Optional[builtins.int]:
        """
        当前实例已用容量。单位：MiB。
        """
        return pulumi.get(self, "used")


@pulumi.output_type
class InstanceConfigureNode(dict):
    def __init__(__self__, *,
                 az: Optional[builtins.str] = None):
        """
        :param builtins.str az: 每个节点所属的可用区。
        """
        if az is not None:
            pulumi.set(__self__, "az", az)

    @property
    @pulumi.getter
    def az(self) -> Optional[builtins.str]:
        """
        每个节点所属的可用区。
        """
        return pulumi.get(self, "az")


@pulumi.output_type
class InstanceInstanceShard(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "nodeNumber":
            suggest = "node_number"
        elif key == "serverNodes":
            suggest = "server_nodes"
        elif key == "shardId":
            suggest = "shard_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceInstanceShard. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceInstanceShard.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceInstanceShard.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 node_number: Optional[builtins.int] = None,
                 server_nodes: Optional[Sequence['outputs.InstanceInstanceShardServerNode']] = None,
                 shard_id: Optional[builtins.str] = None):
        """
        :param builtins.int node_number: 分片中的节点数量
        :param builtins.str shard_id: 分片 ID。
        """
        if node_number is not None:
            pulumi.set(__self__, "node_number", node_number)
        if server_nodes is not None:
            pulumi.set(__self__, "server_nodes", server_nodes)
        if shard_id is not None:
            pulumi.set(__self__, "shard_id", shard_id)

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> Optional[builtins.int]:
        """
        分片中的节点数量
        """
        return pulumi.get(self, "node_number")

    @property
    @pulumi.getter(name="serverNodes")
    def server_nodes(self) -> Optional[Sequence['outputs.InstanceInstanceShardServerNode']]:
        return pulumi.get(self, "server_nodes")

    @property
    @pulumi.getter(name="shardId")
    def shard_id(self) -> Optional[builtins.str]:
        """
        分片 ID。
        """
        return pulumi.get(self, "shard_id")


@pulumi.output_type
class InstanceInstanceShardServerNode(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "currentRole":
            suggest = "current_role"
        elif key == "nodeId":
            suggest = "node_id"
        elif key == "zoneId":
            suggest = "zone_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceInstanceShardServerNode. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceInstanceShardServerNode.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceInstanceShardServerNode.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 current_role: Optional[builtins.str] = None,
                 node_id: Optional[builtins.str] = None,
                 status: Optional[builtins.str] = None,
                 zone_id: Optional[builtins.str] = None):
        """
        :param builtins.str current_role: 节点当前的角色。取值范围如下：PrimaryNode：主节点。SecondaryNode：从节点。
        :param builtins.str node_id: 节点 ID。
        :param builtins.str status: 节点状态。取值范围如下：deploy：启动中。running：运行中。loading：数据加载中。error：错误。
        :param builtins.str zone_id: 节点所在的可用区。
        """
        if current_role is not None:
            pulumi.set(__self__, "current_role", current_role)
        if node_id is not None:
            pulumi.set(__self__, "node_id", node_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="currentRole")
    def current_role(self) -> Optional[builtins.str]:
        """
        节点当前的角色。取值范围如下：PrimaryNode：主节点。SecondaryNode：从节点。
        """
        return pulumi.get(self, "current_role")

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> Optional[builtins.str]:
        """
        节点 ID。
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        节点状态。取值范围如下：deploy：启动中。running：运行中。loading：数据加载中。error：错误。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[builtins.str]:
        """
        节点所在的可用区。
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class InstanceVisitAddr(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "addrType":
            suggest = "addr_type"
        elif key == "eipId":
            suggest = "eip_id"
        elif key == "viPv6":
            suggest = "vi_pv6"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceVisitAddr. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceVisitAddr.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceVisitAddr.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 addr_type: Optional[builtins.str] = None,
                 address: Optional[builtins.str] = None,
                 eip_id: Optional[builtins.str] = None,
                 port: Optional[builtins.str] = None,
                 vi_pv6: Optional[builtins.str] = None,
                 vip: Optional[builtins.str] = None):
        """
        :param builtins.str addr_type: 连接地址类型，取值范围如下：Private：私网连接地址；Public：公网连接地址；DirectLink：直连地址。
        :param builtins.str address: IP 地址或者域名。
        :param builtins.str eip_id: 实例公网地址所绑定的EIP ID。仅当连接地址类型（即AddrType）为Public公网连接地址时，返回该参数。
        :param builtins.str port: 端口号。
        :param builtins.str vi_pv6: 连接地址所对应的 IPv6 地址。
        :param builtins.str vip: 连接地址所对应的 IPv4 地址。
        """
        if addr_type is not None:
            pulumi.set(__self__, "addr_type", addr_type)
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if vi_pv6 is not None:
            pulumi.set(__self__, "vi_pv6", vi_pv6)
        if vip is not None:
            pulumi.set(__self__, "vip", vip)

    @property
    @pulumi.getter(name="addrType")
    def addr_type(self) -> Optional[builtins.str]:
        """
        连接地址类型，取值范围如下：Private：私网连接地址；Public：公网连接地址；DirectLink：直连地址。
        """
        return pulumi.get(self, "addr_type")

    @property
    @pulumi.getter
    def address(self) -> Optional[builtins.str]:
        """
        IP 地址或者域名。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[builtins.str]:
        """
        实例公网地址所绑定的EIP ID。仅当连接地址类型（即AddrType）为Public公网连接地址时，返回该参数。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.str]:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="viPv6")
    def vi_pv6(self) -> Optional[builtins.str]:
        """
        连接地址所对应的 IPv6 地址。
        """
        return pulumi.get(self, "vi_pv6")

    @property
    @pulumi.getter
    def vip(self) -> Optional[builtins.str]:
        """
        连接地址所对应的 IPv4 地址。
        """
        return pulumi.get(self, "vip")


@pulumi.output_type
class GetInstanceCapacityResult(dict):
    def __init__(__self__, *,
                 total: builtins.int,
                 used: builtins.int):
        """
        :param builtins.int total: 当前实例的内存总容量。单位：MiB。
        :param builtins.int used: 当前实例已用容量。单位：MiB。
        """
        pulumi.set(__self__, "total", total)
        pulumi.set(__self__, "used", used)

    @property
    @pulumi.getter
    def total(self) -> builtins.int:
        """
        当前实例的内存总容量。单位：MiB。
        """
        return pulumi.get(self, "total")

    @property
    @pulumi.getter
    def used(self) -> builtins.int:
        """
        当前实例已用容量。单位：MiB。
        """
        return pulumi.get(self, "used")


@pulumi.output_type
class GetInstanceConfigureNodeResult(dict):
    def __init__(__self__, *,
                 az: builtins.str):
        """
        :param builtins.str az: 每个节点所属的可用区。
        """
        pulumi.set(__self__, "az", az)

    @property
    @pulumi.getter
    def az(self) -> builtins.str:
        """
        每个节点所属的可用区。
        """
        return pulumi.get(self, "az")


@pulumi.output_type
class GetInstanceInstanceShardResult(dict):
    def __init__(__self__, *,
                 node_number: builtins.int,
                 server_nodes: Sequence['outputs.GetInstanceInstanceShardServerNodeResult'],
                 shard_id: builtins.str):
        """
        :param builtins.int node_number: 分片中的节点数量
        :param Sequence['GetInstanceInstanceShardServerNodeArgs'] server_nodes: 分片中所有 Server 节点的详情列表。
        :param builtins.str shard_id: 分片 ID。
        """
        pulumi.set(__self__, "node_number", node_number)
        pulumi.set(__self__, "server_nodes", server_nodes)
        pulumi.set(__self__, "shard_id", shard_id)

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> builtins.int:
        """
        分片中的节点数量
        """
        return pulumi.get(self, "node_number")

    @property
    @pulumi.getter(name="serverNodes")
    def server_nodes(self) -> Sequence['outputs.GetInstanceInstanceShardServerNodeResult']:
        """
        分片中所有 Server 节点的详情列表。
        """
        return pulumi.get(self, "server_nodes")

    @property
    @pulumi.getter(name="shardId")
    def shard_id(self) -> builtins.str:
        """
        分片 ID。
        """
        return pulumi.get(self, "shard_id")


@pulumi.output_type
class GetInstanceInstanceShardServerNodeResult(dict):
    def __init__(__self__, *,
                 current_role: builtins.str,
                 node_id: builtins.str,
                 status: builtins.str,
                 zone_id: builtins.str):
        """
        :param builtins.str current_role: 节点当前的角色。取值范围如下：PrimaryNode：主节点。SecondaryNode：从节点。
        :param builtins.str node_id: 节点 ID。
        :param builtins.str status: 节点状态。取值范围如下：deploy：启动中。running：运行中。loading：数据加载中。error：错误。
        :param builtins.str zone_id: 节点所在的可用区。
        """
        pulumi.set(__self__, "current_role", current_role)
        pulumi.set(__self__, "node_id", node_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="currentRole")
    def current_role(self) -> builtins.str:
        """
        节点当前的角色。取值范围如下：PrimaryNode：主节点。SecondaryNode：从节点。
        """
        return pulumi.get(self, "current_role")

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> builtins.str:
        """
        节点 ID。
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        节点状态。取值范围如下：deploy：启动中。running：运行中。loading：数据加载中。error：错误。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        节点所在的可用区。
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceVisitAddrResult(dict):
    def __init__(__self__, *,
                 addr_type: builtins.str,
                 address: builtins.str,
                 eip_id: builtins.str,
                 port: builtins.str,
                 vi_pv6: builtins.str,
                 vip: builtins.str):
        """
        :param builtins.str addr_type: 连接地址类型，取值范围如下：Private：私网连接地址；Public：公网连接地址；DirectLink：直连地址。
        :param builtins.str address: IP 地址或者域名。
        :param builtins.str eip_id: 实例公网地址所绑定的EIP ID。仅当连接地址类型（即AddrType）为Public公网连接地址时，返回该参数。
        :param builtins.str port: 端口号。
        :param builtins.str vi_pv6: 连接地址所对应的 IPv6 地址。
        :param builtins.str vip: 连接地址所对应的 IPv4 地址。
        """
        pulumi.set(__self__, "addr_type", addr_type)
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "eip_id", eip_id)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "vi_pv6", vi_pv6)
        pulumi.set(__self__, "vip", vip)

    @property
    @pulumi.getter(name="addrType")
    def addr_type(self) -> builtins.str:
        """
        连接地址类型，取值范围如下：Private：私网连接地址；Public：公网连接地址；DirectLink：直连地址。
        """
        return pulumi.get(self, "addr_type")

    @property
    @pulumi.getter
    def address(self) -> builtins.str:
        """
        IP 地址或者域名。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        实例公网地址所绑定的EIP ID。仅当连接地址类型（即AddrType）为Public公网连接地址时，返回该参数。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def port(self) -> builtins.str:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="viPv6")
    def vi_pv6(self) -> builtins.str:
        """
        连接地址所对应的 IPv6 地址。
        """
        return pulumi.get(self, "vi_pv6")

    @property
    @pulumi.getter
    def vip(self) -> builtins.str:
        """
        连接地址所对应的 IPv4 地址。
        """
        return pulumi.get(self, "vip")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSnapshotResult',
    'AwaitableGetSnapshotResult',
    'get_snapshot',
    'get_snapshot_output',
]

@pulumi.output_type
class GetSnapshotResult:
    """
    A collection of values returned by getSnapshot.
    """
    def __init__(__self__, creation_time=None, description=None, id=None, image_id=None, instant_access=None, progress=None, project_name=None, retention_days=None, shared=None, snapshot_group_id=None, snapshot_id=None, snapshot_name=None, snapshot_type=None, status=None, tags=None, volume_id=None, volume_kind=None, volume_name=None, volume_size=None, volume_status=None, volume_type=None, zone_id=None):
        if creation_time and not isinstance(creation_time, str):
            raise TypeError("Expected argument 'creation_time' to be a str")
        pulumi.set(__self__, "creation_time", creation_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if instant_access and not isinstance(instant_access, bool):
            raise TypeError("Expected argument 'instant_access' to be a bool")
        pulumi.set(__self__, "instant_access", instant_access)
        if progress and not isinstance(progress, int):
            raise TypeError("Expected argument 'progress' to be a int")
        pulumi.set(__self__, "progress", progress)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if retention_days and not isinstance(retention_days, int):
            raise TypeError("Expected argument 'retention_days' to be a int")
        pulumi.set(__self__, "retention_days", retention_days)
        if shared and not isinstance(shared, bool):
            raise TypeError("Expected argument 'shared' to be a bool")
        pulumi.set(__self__, "shared", shared)
        if snapshot_group_id and not isinstance(snapshot_group_id, str):
            raise TypeError("Expected argument 'snapshot_group_id' to be a str")
        pulumi.set(__self__, "snapshot_group_id", snapshot_group_id)
        if snapshot_id and not isinstance(snapshot_id, str):
            raise TypeError("Expected argument 'snapshot_id' to be a str")
        pulumi.set(__self__, "snapshot_id", snapshot_id)
        if snapshot_name and not isinstance(snapshot_name, str):
            raise TypeError("Expected argument 'snapshot_name' to be a str")
        pulumi.set(__self__, "snapshot_name", snapshot_name)
        if snapshot_type and not isinstance(snapshot_type, str):
            raise TypeError("Expected argument 'snapshot_type' to be a str")
        pulumi.set(__self__, "snapshot_type", snapshot_type)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if volume_id and not isinstance(volume_id, str):
            raise TypeError("Expected argument 'volume_id' to be a str")
        pulumi.set(__self__, "volume_id", volume_id)
        if volume_kind and not isinstance(volume_kind, str):
            raise TypeError("Expected argument 'volume_kind' to be a str")
        pulumi.set(__self__, "volume_kind", volume_kind)
        if volume_name and not isinstance(volume_name, str):
            raise TypeError("Expected argument 'volume_name' to be a str")
        pulumi.set(__self__, "volume_name", volume_name)
        if volume_size and not isinstance(volume_size, int):
            raise TypeError("Expected argument 'volume_size' to be a int")
        pulumi.set(__self__, "volume_size", volume_size)
        if volume_status and not isinstance(volume_status, str):
            raise TypeError("Expected argument 'volume_status' to be a str")
        pulumi.set(__self__, "volume_status", volume_status)
        if volume_type and not isinstance(volume_type, str):
            raise TypeError("Expected argument 'volume_type' to be a str")
        pulumi.set(__self__, "volume_type", volume_type)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> builtins.str:
        """
        快照创建时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        快照描述信息，默认为空，长度限制为0~255个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        镜像ID
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instantAccess")
    def instant_access(self) -> builtins.bool:
        """
        快照是否开启极速可用能力，取值说明如下：true：已开启极速可用能力。false：未开启极速可用能力。
        """
        return pulumi.get(self, "instant_access")

    @property
    @pulumi.getter
    def progress(self) -> builtins.int:
        """
        快照转储进度。
        """
        return pulumi.get(self, "progress")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        快照所要加入的Project（项目）名称。注意快照不会继承云盘的项目，即快照与云盘可以所属不同的项目。如果您在创建快照时未设置ProjectName，快照会默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> builtins.int:
        """
        快照保留时间，单位为天，取值说明如下：空：永久保留快照 。1~65536：指定保存天数。默认为空，即默认永久保留快照。说明快照保留时间从快照创建时刻开始计算。
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter
    def shared(self) -> builtins.bool:
        """
        快照是否共享。
        """
        return pulumi.get(self, "shared")

    @property
    @pulumi.getter(name="snapshotGroupId")
    def snapshot_group_id(self) -> builtins.str:
        """
        快照一致性组ID。
        """
        return pulumi.get(self, "snapshot_group_id")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> builtins.str:
        """
        快照ID。
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter(name="snapshotName")
    def snapshot_name(self) -> builtins.str:
        """
        创建的快照名称。命名规范如下：长度限制为1~128个字符。只能包含中文、字母、数字、下划线（_）、中划线（-）和英文句号（.）。为防止和自动快照的名称冲突，不能以“auto”开头。
        """
        return pulumi.get(self, "snapshot_name")

    @property
    @pulumi.getter(name="snapshotType")
    def snapshot_type(self) -> builtins.str:
        """
        快照类型，取值说明如下：user：查询手动快照。auto：查询自动快照。share：查询共享快照。默认查询所有快照。
        """
        return pulumi.get(self, "snapshot_type")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        快照状态，取值说明如下：available：可用。creating：创建中。rollbacking：回滚中。deleted：已删除。failed：错误。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetSnapshotTagResult']:
        """
        快照的标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> builtins.str:
        """
        快照相关的云盘ID。
        """
        return pulumi.get(self, "volume_id")

    @property
    @pulumi.getter(name="volumeKind")
    def volume_kind(self) -> builtins.str:
        """
        云盘种类，取值说明如下：system：系统盘。data：数据盘。
        """
        return pulumi.get(self, "volume_kind")

    @property
    @pulumi.getter(name="volumeName")
    def volume_name(self) -> builtins.str:
        """
        云盘名称。
        """
        return pulumi.get(self, "volume_name")

    @property
    @pulumi.getter(name="volumeSize")
    def volume_size(self) -> builtins.int:
        """
        云盘大小，单位为GiB。
        """
        return pulumi.get(self, "volume_size")

    @property
    @pulumi.getter(name="volumeStatus")
    def volume_status(self) -> builtins.str:
        """
        云盘状态，取值说明如下：available：可用, attaching：挂载中, attached：已挂载, detaching：卸载中, creating：创建中, deleting：删除中, error：错误, extending：扩容中, ""：云盘被删除。
        """
        return pulumi.get(self, "volume_status")

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> builtins.str:
        """
        云盘类型，取值说明如下：ESSD*PL0：极速型SSD云盘，PL0规格。ESSD*FlexPL：极速型SSD云盘，FlexPL规格。TSSD_TL0：吞吐型SSD云盘
        """
        return pulumi.get(self, "volume_type")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        快照所在的可用区ID。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetSnapshotResult(GetSnapshotResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSnapshotResult(
            creation_time=self.creation_time,
            description=self.description,
            id=self.id,
            image_id=self.image_id,
            instant_access=self.instant_access,
            progress=self.progress,
            project_name=self.project_name,
            retention_days=self.retention_days,
            shared=self.shared,
            snapshot_group_id=self.snapshot_group_id,
            snapshot_id=self.snapshot_id,
            snapshot_name=self.snapshot_name,
            snapshot_type=self.snapshot_type,
            status=self.status,
            tags=self.tags,
            volume_id=self.volume_id,
            volume_kind=self.volume_kind,
            volume_name=self.volume_name,
            volume_size=self.volume_size,
            volume_status=self.volume_status,
            volume_type=self.volume_type,
            zone_id=self.zone_id)


def get_snapshot(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSnapshotResult:
    """
    Data Source schema for Byteplus::StorageEBS::Snapshot


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:storageebs/getSnapshot:getSnapshot', __args__, opts=opts, typ=GetSnapshotResult).value

    return AwaitableGetSnapshotResult(
        creation_time=pulumi.get(__ret__, 'creation_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        image_id=pulumi.get(__ret__, 'image_id'),
        instant_access=pulumi.get(__ret__, 'instant_access'),
        progress=pulumi.get(__ret__, 'progress'),
        project_name=pulumi.get(__ret__, 'project_name'),
        retention_days=pulumi.get(__ret__, 'retention_days'),
        shared=pulumi.get(__ret__, 'shared'),
        snapshot_group_id=pulumi.get(__ret__, 'snapshot_group_id'),
        snapshot_id=pulumi.get(__ret__, 'snapshot_id'),
        snapshot_name=pulumi.get(__ret__, 'snapshot_name'),
        snapshot_type=pulumi.get(__ret__, 'snapshot_type'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        volume_id=pulumi.get(__ret__, 'volume_id'),
        volume_kind=pulumi.get(__ret__, 'volume_kind'),
        volume_name=pulumi.get(__ret__, 'volume_name'),
        volume_size=pulumi.get(__ret__, 'volume_size'),
        volume_status=pulumi.get(__ret__, 'volume_status'),
        volume_type=pulumi.get(__ret__, 'volume_type'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_snapshot_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSnapshotResult]:
    """
    Data Source schema for Byteplus::StorageEBS::Snapshot


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:storageebs/getSnapshot:getSnapshot', __args__, opts=opts, typ=GetSnapshotResult)
    return __ret__.apply(lambda __response__: GetSnapshotResult(
        creation_time=pulumi.get(__response__, 'creation_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        image_id=pulumi.get(__response__, 'image_id'),
        instant_access=pulumi.get(__response__, 'instant_access'),
        progress=pulumi.get(__response__, 'progress'),
        project_name=pulumi.get(__response__, 'project_name'),
        retention_days=pulumi.get(__response__, 'retention_days'),
        shared=pulumi.get(__response__, 'shared'),
        snapshot_group_id=pulumi.get(__response__, 'snapshot_group_id'),
        snapshot_id=pulumi.get(__response__, 'snapshot_id'),
        snapshot_name=pulumi.get(__response__, 'snapshot_name'),
        snapshot_type=pulumi.get(__response__, 'snapshot_type'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        volume_id=pulumi.get(__response__, 'volume_id'),
        volume_kind=pulumi.get(__response__, 'volume_kind'),
        volume_name=pulumi.get(__response__, 'volume_name'),
        volume_size=pulumi.get(__response__, 'volume_size'),
        volume_status=pulumi.get(__response__, 'volume_status'),
        volume_type=pulumi.get(__response__, 'volume_type'),
        zone_id=pulumi.get(__response__, 'zone_id')))
